from .alexnet import AlexNet, TFAlexNet
from .vgg import VGG16, VGG19, TFVGG16, TFVGG19
from .inceptionv1 import InceptionNetV1, TFInceptionNetV1
from .resnetv1 import TFResNet50V1, ResNet50V1
